import React, { useState } from "react";
import styled from "styled-components";
import Button from "../../util/Button";
import { dispatch, usePlayerName } from "../../../domain/gameStore";

const FormInput = styled.input`
  border-radius: 0px;
  border: #666 solid 1px;
  background-color: #181a1b;
  color: #eee;
  padding: 0.5em;
  margin-left: 2em;
  margin-right: 2em;
  height: 100%;
`

const NameInputGroup = styled.div`
  display: flex;
  flex-flow: column nowrap;
  justify-content: space-between;
  align-items: center;
  margin-bottom: 1em;

  @media only screen and (min-width: 600px) and (min-height: 600px) {
    flex-flow: row nowrap;
  }
`

const ErrMsg = styled.div`
  height: 1em;
  text-align: center;
`

export default ({ onJoined }) => {
  const playerName = usePlayerName();
  const [loading, setLoading] = useState(false);
  const [failed, setFailed] = useState(false);

  const onJoinGame = async () => {
    // TODO would like to support re-joining a game you left
    setFailed(false);
    setLoading(true);
    try {
      await dispatch.joinGame();
    } catch (err) {
      // failed to join the game
      setFailed(true);
      setLoading(false);
      return;
    }
    onJoined();
  };
  const cannotJoinGame = loading || !playerName || playerName.length === 0;

  return (
    <>
      <NameInputGroup>
        Enter your name to join:
        <FormInput
          type="text"
          value={playerName || ""} 
          onChange={({ target }) => dispatch.setPlayerName(target.value)}
          onKeyDown={({ key }) => { if (key === "Enter") { onJoinGame() }}}
        />
        <Button onClick={onJoinGame} disabled={cannotJoinGame}>Join Game</Button>
      </NameInputGroup>
      <ErrMsg>{failed ? "Failed to join the game! Maybe try a different name?" : ""}</ErrMsg>
    </>
  );
};
