import React, { useRef, useEffect, useState } from "react";
import styled from "styled-components";
import useMap from '../../../hooks/useMap';
import useMarkersFromGuesses from '../../../hooks/useMarkersFromGuesses';

const RoundSelectContainer = styled.div`
  /* background-color: #444; */
  height: 100%;
  display: flex;
  flex-flow: column wrap;
  justify-content: flex-start;
  align-items: center;
  align-content: flex-start;
`;

const RoundSelectButton = styled.div`
  background-color: ${({active}) => active ? "#777" : "#555"};
  height: 2em;
  width: 2em;
  margin-top: 1px;
  margin-bottom: 2px;
  border-radius: 0% 20% 20% 0%;
  cursor: pointer;
  display: flex;
  justify-content: center;
  align-items: center;
`;

const ResetRoundSelectButton = styled(RoundSelectButton).attrs({
  active: false,
})`
  margin-top: auto;
  margin-bottom: 0px;
`;

const MapDiv = styled.div`
  height: 100%;
  width: 60vw;
  border: #555 solid 2px;
`;

const MapContainer = styled.div`
  height: 350px;
  padding: 2px;
  display: flex;
  justify-content: center;
  align-items: center;
`;

export default ({ players, coords }) => {
  const rounds = Object.keys(coords).length;
  const singleRound = rounds === 1;

  // create the map
  const mapDivRef = useRef(null);
  const mapRef = useMap(mapDivRef, 0, 0, 1);

  // set up round number selection
  const [roundNum, setRoundNum] = useState("0");
  const roundActive = singleRound ? "1" : roundNum;

  // get the target point
  const targetPoint = coords?.[roundActive] ?? null;

  // put the markers on the map
  useMarkersFromGuesses(mapRef, players, roundActive, targetPoint);

  // scroll the map to the target point
  useEffect(() => {
    mapRef.current && mapRef.current.panTo(targetPoint ?? { lat: 0, lng: 0 });
  }, [mapRef, targetPoint]);

  const roundSelect = singleRound
    ? null
    : (
      <RoundSelectContainer>
        { 
          // fun fact: es6 doesn't have a range(x) function
          Array.from(Array(rounds).keys())
            .map(r => (r + 1).toString())
            .map(r => <RoundSelectButton active={r === roundNum} key={r} onClick={() => setRoundNum(r)}>{r}</RoundSelectButton>)
        }
        <ResetRoundSelectButton onClick={() => setRoundNum("0")}>X</ResetRoundSelectButton>
      </RoundSelectContainer>
    )

  return (
    <MapContainer>
      <MapDiv ref={mapDivRef}/>
      { roundSelect }
    </MapContainer>
  );
}
