import { useState, useEffect } from 'react';
import dequal from 'dequal';
import { gameInfo } from '../domain/apiMethods';
import { useGameId } from '../domain/gameStore';

export default () => {
  const gameId = useGameId();
  const [info, setInfo] = useState({});

  useEffect(() => {
    // define how to fetch scores
    const fetchInfo = async () => {
      const newInfo = await gameInfo(gameId);
      // TODO maybe have back-end provide timestamp? to avoid this check
      if (!dequal(info, newInfo)) {
        setInfo(newInfo);
      }
    };
    // when the hook triggers, fetch the game info
    fetchInfo();
    // and do it again every 5 seconds after
    const interval = setInterval(() => fetchInfo(), 5000);
    // and return a clean-up callback
    return () => { clearInterval(interval) };
  }, [gameId, info]);

  return info;
}
